# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class ProjectServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def project_service_activate_schedule_for_project(self, body, project_id_uuid, schedule_id_uuid, **kwargs):  # noqa: E501
        """ActivateScheduleForProject  # noqa: E501

        Add a Schedule to run automatic tests for a Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_activate_schedule_for_project(body, project_id_uuid, schedule_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScheduleIdUuidActivateBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :param str schedule_id_uuid: Unique object ID. (required)
        :return: ProjectActivateScheduleForProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_activate_schedule_for_project_with_http_info(body, project_id_uuid, schedule_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_activate_schedule_for_project_with_http_info(body, project_id_uuid, schedule_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_activate_schedule_for_project_with_http_info(self, body, project_id_uuid, schedule_id_uuid, **kwargs):  # noqa: E501
        """ActivateScheduleForProject  # noqa: E501

        Add a Schedule to run automatic tests for a Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_activate_schedule_for_project_with_http_info(body, project_id_uuid, schedule_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScheduleIdUuidActivateBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :param str schedule_id_uuid: Unique object ID. (required)
        :return: ProjectActivateScheduleForProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id_uuid', 'schedule_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_activate_schedule_for_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `project_service_activate_schedule_for_project`")  # noqa: E501
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_activate_schedule_for_project`")  # noqa: E501
        # verify the required parameter 'schedule_id_uuid' is set
        if ('schedule_id_uuid' not in params or
                params['schedule_id_uuid'] is None):
            raise ValueError("Missing the required parameter `schedule_id_uuid` when calling `project_service_activate_schedule_for_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501
        if 'schedule_id_uuid' in params:
            path_params['scheduleId.uuid'] = params['schedule_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/projects/{projectId.uuid}/schedule/{scheduleId.uuid}/activate', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectActivateScheduleForProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_add_users_to_project(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """AddUsersToProject  # noqa: E501

        Grants existing Organization users permissions to a Project for a given Project ID, based on the pairs of role and User ID provided in the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_add_users_to_project(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RoleUsersBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectAddUsersToProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_add_users_to_project_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_add_users_to_project_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_add_users_to_project_with_http_info(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """AddUsersToProject  # noqa: E501

        Grants existing Organization users permissions to a Project for a given Project ID, based on the pairs of role and User ID provided in the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_add_users_to_project_with_http_info(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RoleUsersBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectAddUsersToProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_add_users_to_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `project_service_add_users_to_project`")  # noqa: E501
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_add_users_to_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId.uuid}/role/users', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectAddUsersToProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_create_project(self, body, **kwargs):  # noqa: E501
        """CreateProject  # noqa: E501

        Creates a Project with required fields. Project is an organizational entity under a Workspace that contains Test Runs, Continuous Tests, and Stress Tests, along with their configurations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_create_project(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectCreateProjectRequest body: (required)
        :return: ProjectCreateProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_create_project_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_create_project_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def project_service_create_project_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateProject  # noqa: E501

        Creates a Project with required fields. Project is an organizational entity under a Workspace that contains Test Runs, Continuous Tests, and Stress Tests, along with their configurations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_create_project_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectCreateProjectRequest body: (required)
        :return: ProjectCreateProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_create_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `project_service_create_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectCreateProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_deactivate_schedule_for_project(self, body, project_id_uuid, schedule_id_uuid, **kwargs):  # noqa: E501
        """DeactivateScheduleForProject  # noqa: E501

        Remove a Schedule from a Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_deactivate_schedule_for_project(body, project_id_uuid, schedule_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScheduleIdUuidDeactivateBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :param str schedule_id_uuid: Unique object ID. (required)
        :return: ProjectDeactivateScheduleForProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_deactivate_schedule_for_project_with_http_info(body, project_id_uuid, schedule_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_deactivate_schedule_for_project_with_http_info(body, project_id_uuid, schedule_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_deactivate_schedule_for_project_with_http_info(self, body, project_id_uuid, schedule_id_uuid, **kwargs):  # noqa: E501
        """DeactivateScheduleForProject  # noqa: E501

        Remove a Schedule from a Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_deactivate_schedule_for_project_with_http_info(body, project_id_uuid, schedule_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScheduleIdUuidDeactivateBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :param str schedule_id_uuid: Unique object ID. (required)
        :return: ProjectDeactivateScheduleForProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id_uuid', 'schedule_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_deactivate_schedule_for_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `project_service_deactivate_schedule_for_project`")  # noqa: E501
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_deactivate_schedule_for_project`")  # noqa: E501
        # verify the required parameter 'schedule_id_uuid' is set
        if ('schedule_id_uuid' not in params or
                params['schedule_id_uuid'] is None):
            raise ValueError("Missing the required parameter `schedule_id_uuid` when calling `project_service_deactivate_schedule_for_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501
        if 'schedule_id_uuid' in params:
            path_params['scheduleId.uuid'] = params['schedule_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/projects/{projectId.uuid}/schedule/{scheduleId.uuid}/deactivate', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectDeactivateScheduleForProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_delete_project(self, project_id_uuid, **kwargs):  # noqa: E501
        """DeleteProject  # noqa: E501

        Deletes a Project for a given Project ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_delete_project(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectDeleteProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_delete_project_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_delete_project_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_delete_project_with_http_info(self, project_id_uuid, **kwargs):  # noqa: E501
        """DeleteProject  # noqa: E501

        Deletes a Project for a given Project ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_delete_project_with_http_info(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectDeleteProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_delete_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_delete_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectDeleteProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_get_project(self, project_id_uuid, **kwargs):  # noqa: E501
        """GetProject  # noqa: E501

        Returns a Project for a given Project ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_get_project(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectGetProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_get_project_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_get_project_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_get_project_with_http_info(self, project_id_uuid, **kwargs):  # noqa: E501
        """GetProject  # noqa: E501

        Returns a Project for a given Project ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_get_project_with_http_info(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectGetProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_get_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_get_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectGetProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_get_project_url(self, project_id_uuid, **kwargs):  # noqa: E501
        """GetProjectURL  # noqa: E501

        Return the URL of a Project for a given Project ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_get_project_url(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectGetProjectURLResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_get_project_url_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_get_project_url_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_get_project_url_with_http_info(self, project_id_uuid, **kwargs):  # noqa: E501
        """GetProjectURL  # noqa: E501

        Return the URL of a Project for a given Project ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_get_project_url_with_http_info(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectGetProjectURLResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_get_project_url" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_get_project_url`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId.uuid}/url', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectGetProjectURLResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_get_workspace_roles_for_project(self, project_id_uuid, **kwargs):  # noqa: E501
        """GetWorkspaceRoleForProject  # noqa: E501

        Returns the permissions of the Workspace members for a Project given Project ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_get_workspace_roles_for_project(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectGetWorkspaceRolesForProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_get_workspace_roles_for_project_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_get_workspace_roles_for_project_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_get_workspace_roles_for_project_with_http_info(self, project_id_uuid, **kwargs):  # noqa: E501
        """GetWorkspaceRoleForProject  # noqa: E501

        Returns the permissions of the Workspace members for a Project given Project ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_get_workspace_roles_for_project_with_http_info(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectGetWorkspaceRolesForProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_get_workspace_roles_for_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_get_workspace_roles_for_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId.uuid}/role/workspace', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectGetWorkspaceRolesForProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_list_projects(self, **kwargs):  # noqa: E501
        """ListProjects  # noqa: E501

        Returns a paginated list of Projects for a given Workspace ID. Filters out Projects that the user does not have access to. The list is sorted by the last test run time field of each Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_list_projects(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID.
        :param bool first_page_query_is_published: Optional: If true, return published projects. If false, return unpublished projects. If not specified, return all projects.
        :param datetime first_page_query_creation_time_range_start_time:
        :param datetime first_page_query_creation_time_range_end_time:
        :param datetime first_page_query_last_test_run_time_range_start_time:
        :param datetime first_page_query_last_test_run_time_range_end_time:
        :param list[str] first_page_query_stress_test_categories: Optional: When specified, return all projects whose ST categories are a superset of the ST categories provided here.
        :param list[str] first_page_query_continuous_test_categories: Optional: When specified, return all projects whose CT categories are a superset of the CT categories provided here.
        :param str first_page_query_owner_email: Optional: When specified, return all projects whose owner email matches.
        :param list[str] first_page_query_model_tasks: Optional: When specified, return all projects whose model task is the provided model task.
        :param str first_page_query_status: Optional: When specified, return all projects whose status is the provided status.
        :param str first_page_query_sort_sort_order:
        :param str first_page_query_sort_sort_by:
        :param str first_page_query_search_expression:
        :param list[str] first_page_query_search_search_fields:
        :param str page_token: Specifies a page of the list returned by a ListProjects query. The ListProjects query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageQuery field.
        :param str page_size: The maximum number of Project objects to return in a single page.
        :return: ProjectListProjectsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_list_projects_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.project_service_list_projects_with_http_info(**kwargs)  # noqa: E501
            return data

    def project_service_list_projects_with_http_info(self, **kwargs):  # noqa: E501
        """ListProjects  # noqa: E501

        Returns a paginated list of Projects for a given Workspace ID. Filters out Projects that the user does not have access to. The list is sorted by the last test run time field of each Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_list_projects_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_id_uuid: Unique object ID.
        :param bool first_page_query_is_published: Optional: If true, return published projects. If false, return unpublished projects. If not specified, return all projects.
        :param datetime first_page_query_creation_time_range_start_time:
        :param datetime first_page_query_creation_time_range_end_time:
        :param datetime first_page_query_last_test_run_time_range_start_time:
        :param datetime first_page_query_last_test_run_time_range_end_time:
        :param list[str] first_page_query_stress_test_categories: Optional: When specified, return all projects whose ST categories are a superset of the ST categories provided here.
        :param list[str] first_page_query_continuous_test_categories: Optional: When specified, return all projects whose CT categories are a superset of the CT categories provided here.
        :param str first_page_query_owner_email: Optional: When specified, return all projects whose owner email matches.
        :param list[str] first_page_query_model_tasks: Optional: When specified, return all projects whose model task is the provided model task.
        :param str first_page_query_status: Optional: When specified, return all projects whose status is the provided status.
        :param str first_page_query_sort_sort_order:
        :param str first_page_query_sort_sort_by:
        :param str first_page_query_search_expression:
        :param list[str] first_page_query_search_search_fields:
        :param str page_token: Specifies a page of the list returned by a ListProjects query. The ListProjects query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageQuery field.
        :param str page_size: The maximum number of Project objects to return in a single page.
        :return: ProjectListProjectsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace_id_uuid', 'first_page_query_is_published', 'first_page_query_creation_time_range_start_time', 'first_page_query_creation_time_range_end_time', 'first_page_query_last_test_run_time_range_start_time', 'first_page_query_last_test_run_time_range_end_time', 'first_page_query_stress_test_categories', 'first_page_query_continuous_test_categories', 'first_page_query_owner_email', 'first_page_query_model_tasks', 'first_page_query_status', 'first_page_query_sort_sort_order', 'first_page_query_sort_sort_by', 'first_page_query_search_expression', 'first_page_query_search_search_fields', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_list_projects" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'workspace_id_uuid' in params:
            query_params.append(('workspaceId.uuid', params['workspace_id_uuid']))  # noqa: E501
        if 'first_page_query_is_published' in params:
            query_params.append(('firstPageQuery.isPublished', params['first_page_query_is_published']))  # noqa: E501
        if 'first_page_query_creation_time_range_start_time' in params:
            query_params.append(('firstPageQuery.creationTimeRange.startTime', params['first_page_query_creation_time_range_start_time']))  # noqa: E501
        if 'first_page_query_creation_time_range_end_time' in params:
            query_params.append(('firstPageQuery.creationTimeRange.endTime', params['first_page_query_creation_time_range_end_time']))  # noqa: E501
        if 'first_page_query_last_test_run_time_range_start_time' in params:
            query_params.append(('firstPageQuery.lastTestRunTimeRange.startTime', params['first_page_query_last_test_run_time_range_start_time']))  # noqa: E501
        if 'first_page_query_last_test_run_time_range_end_time' in params:
            query_params.append(('firstPageQuery.lastTestRunTimeRange.endTime', params['first_page_query_last_test_run_time_range_end_time']))  # noqa: E501
        if 'first_page_query_stress_test_categories' in params:
            query_params.append(('firstPageQuery.stressTestCategories', params['first_page_query_stress_test_categories']))  # noqa: E501
            collection_formats['firstPageQuery.stressTestCategories'] = 'multi'  # noqa: E501
        if 'first_page_query_continuous_test_categories' in params:
            query_params.append(('firstPageQuery.continuousTestCategories', params['first_page_query_continuous_test_categories']))  # noqa: E501
            collection_formats['firstPageQuery.continuousTestCategories'] = 'multi'  # noqa: E501
        if 'first_page_query_owner_email' in params:
            query_params.append(('firstPageQuery.ownerEmail', params['first_page_query_owner_email']))  # noqa: E501
        if 'first_page_query_model_tasks' in params:
            query_params.append(('firstPageQuery.modelTasks', params['first_page_query_model_tasks']))  # noqa: E501
            collection_formats['firstPageQuery.modelTasks'] = 'multi'  # noqa: E501
        if 'first_page_query_status' in params:
            query_params.append(('firstPageQuery.status', params['first_page_query_status']))  # noqa: E501
        if 'first_page_query_sort_sort_order' in params:
            query_params.append(('firstPageQuery.sort.sortOrder', params['first_page_query_sort_sort_order']))  # noqa: E501
        if 'first_page_query_sort_sort_by' in params:
            query_params.append(('firstPageQuery.sort.sortBy', params['first_page_query_sort_sort_by']))  # noqa: E501
        if 'first_page_query_search_expression' in params:
            query_params.append(('firstPageQuery.search.expression', params['first_page_query_search_expression']))  # noqa: E501
        if 'first_page_query_search_search_fields' in params:
            query_params.append(('firstPageQuery.search.searchFields', params['first_page_query_search_search_fields']))  # noqa: E501
            collection_formats['firstPageQuery.search.searchFields'] = 'multi'  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectListProjectsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_list_users_of_project(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListUsersOfProject  # noqa: E501

        Lists the users and their roles of a Project for a given Project ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_list_users_of_project(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str page_token: Specifies a page of the list returned by a ListUsersOfProject query. The ListUsersOfProject query returns a pageToken when there is more than one page of results.
        :param str page_size: The maximum number of User objects to return in a single page.
        :return: ProjectListUsersOfProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_list_users_of_project_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_list_users_of_project_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_list_users_of_project_with_http_info(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListUsersOfProject  # noqa: E501

        Lists the users and their roles of a Project for a given Project ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_list_users_of_project_with_http_info(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str page_token: Specifies a page of the list returned by a ListUsersOfProject query. The ListUsersOfProject query returns a pageToken when there is more than one page of results.
        :param str page_size: The maximum number of User objects to return in a single page.
        :return: ProjectListUsersOfProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_list_users_of_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_list_users_of_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId.uuid}/role/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectListUsersOfProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_remove_user_from_project(self, project_id_uuid, user_id_uuid, **kwargs):  # noqa: E501
        """RemoveUserFromProject  # noqa: E501

        Removes all existing permissions of a user from a Project given Project ID and User ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_remove_user_from_project(project_id_uuid, user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str user_id_uuid: Unique object ID. (required)
        :return: ProjectRemoveUserFromProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_remove_user_from_project_with_http_info(project_id_uuid, user_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_remove_user_from_project_with_http_info(project_id_uuid, user_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_remove_user_from_project_with_http_info(self, project_id_uuid, user_id_uuid, **kwargs):  # noqa: E501
        """RemoveUserFromProject  # noqa: E501

        Removes all existing permissions of a user from a Project given Project ID and User ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_remove_user_from_project_with_http_info(project_id_uuid, user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str user_id_uuid: Unique object ID. (required)
        :return: ProjectRemoveUserFromProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid', 'user_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_remove_user_from_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_remove_user_from_project`")  # noqa: E501
        # verify the required parameter 'user_id_uuid' is set
        if ('user_id_uuid' not in params or
                params['user_id_uuid'] is None):
            raise ValueError("Missing the required parameter `user_id_uuid` when calling `project_service_remove_user_from_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501
        if 'user_id_uuid' in params:
            path_params['userId.uuid'] = params['user_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId.uuid}/role/users/{userId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectRemoveUserFromProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_update_project(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """UpdateProject  # noqa: E501

        Updates a Project for a given Project ID. Only updates the fields specified in the FieldMask.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_update_project(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectsProjectIdUuidBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectUpdateProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_update_project_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_update_project_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_update_project_with_http_info(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """UpdateProject  # noqa: E501

        Updates a Project for a given Project ID. Only updates the fields specified in the FieldMask.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_update_project_with_http_info(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectsProjectIdUuidBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectUpdateProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_update_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `project_service_update_project`")  # noqa: E501
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_update_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId.uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectUpdateProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_update_user_of_project(self, body, project_id_uuid, user_user_id_uuid, **kwargs):  # noqa: E501
        """UpdateUserOfProject  # noqa: E501

        Updates the existing permission of a user of a Project given Project ID and User ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_update_user_of_project(body, project_id_uuid, user_user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UsersUserUserIdUuidBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :param str user_user_id_uuid: Unique object ID. (required)
        :return: ProjectUpdateUserOfProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_update_user_of_project_with_http_info(body, project_id_uuid, user_user_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_update_user_of_project_with_http_info(body, project_id_uuid, user_user_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_update_user_of_project_with_http_info(self, body, project_id_uuid, user_user_id_uuid, **kwargs):  # noqa: E501
        """UpdateUserOfProject  # noqa: E501

        Updates the existing permission of a user of a Project given Project ID and User ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_update_user_of_project_with_http_info(body, project_id_uuid, user_user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UsersUserUserIdUuidBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :param str user_user_id_uuid: Unique object ID. (required)
        :return: ProjectUpdateUserOfProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id_uuid', 'user_user_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_update_user_of_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `project_service_update_user_of_project`")  # noqa: E501
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_update_user_of_project`")  # noqa: E501
        # verify the required parameter 'user_user_id_uuid' is set
        if ('user_user_id_uuid' not in params or
                params['user_user_id_uuid'] is None):
            raise ValueError("Missing the required parameter `user_user_id_uuid` when calling `project_service_update_user_of_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501
        if 'user_user_id_uuid' in params:
            path_params['user.userId.uuid'] = params['user_user_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId.uuid}/role/users/{user.userId.uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectUpdateUserOfProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_service_update_workspace_roles_for_project(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """UpdateWorkspaceRoleForProject  # noqa: E501

        Assigns users roles(permissions) on a Project based on their roles in the Workspace that contains the Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_update_workspace_roles_for_project(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RoleWorkspaceBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectUpdateWorkspaceRolesForProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_service_update_workspace_roles_for_project_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.project_service_update_workspace_roles_for_project_with_http_info(body, project_id_uuid, **kwargs)  # noqa: E501
            return data

    def project_service_update_workspace_roles_for_project_with_http_info(self, body, project_id_uuid, **kwargs):  # noqa: E501
        """UpdateWorkspaceRoleForProject  # noqa: E501

        Assigns users roles(permissions) on a Project based on their roles in the Workspace that contains the Project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_service_update_workspace_roles_for_project_with_http_info(body, project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RoleWorkspaceBody body: (required)
        :param str project_id_uuid: Unique object ID. (required)
        :return: ProjectUpdateWorkspaceRolesForProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_service_update_workspace_roles_for_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `project_service_update_workspace_roles_for_project`")  # noqa: E501
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `project_service_update_workspace_roles_for_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId.uuid}/role/workspace', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProjectUpdateWorkspaceRolesForProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeGetRIMEInfoResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_info_version': 'str',
        'customer_name': 'str',
        'expiration_time': 'datetime',
        'grace_period_end_time': 'datetime',
        'ri_plan': 'RimeRIPlan',
        'build_version': 'str'
    }

    attribute_map = {
        'cluster_info_version': 'clusterInfoVersion',
        'customer_name': 'customerName',
        'expiration_time': 'expirationTime',
        'grace_period_end_time': 'gracePeriodEndTime',
        'ri_plan': 'riPlan',
        'build_version': 'buildVersion'
    }

    def __init__(self, cluster_info_version=None, customer_name=None, expiration_time=None, grace_period_end_time=None, ri_plan=None, build_version=None):  # noqa: E501
        """RimeGetRIMEInfoResponse - a model defined in Swagger"""  # noqa: E501
        self._cluster_info_version = None
        self._customer_name = None
        self._expiration_time = None
        self._grace_period_end_time = None
        self._ri_plan = None
        self._build_version = None
        self.discriminator = None
        if cluster_info_version is not None:
            self.cluster_info_version = cluster_info_version
        if customer_name is not None:
            self.customer_name = customer_name
        if expiration_time is not None:
            self.expiration_time = expiration_time
        if grace_period_end_time is not None:
            self.grace_period_end_time = grace_period_end_time
        if ri_plan is not None:
            self.ri_plan = ri_plan
        if build_version is not None:
            self.build_version = build_version

    @property
    def cluster_info_version(self):
        """Gets the cluster_info_version of this RimeGetRIMEInfoResponse.  # noqa: E501

        Version of the Robust Intelligence cluster control plane.  # noqa: E501

        :return: The cluster_info_version of this RimeGetRIMEInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._cluster_info_version

    @cluster_info_version.setter
    def cluster_info_version(self, cluster_info_version):
        """Sets the cluster_info_version of this RimeGetRIMEInfoResponse.

        Version of the Robust Intelligence cluster control plane.  # noqa: E501

        :param cluster_info_version: The cluster_info_version of this RimeGetRIMEInfoResponse.  # noqa: E501
        :type: str
        """

        self._cluster_info_version = cluster_info_version

    @property
    def customer_name(self):
        """Gets the customer_name of this RimeGetRIMEInfoResponse.  # noqa: E501

        Name of the customer who owns the license.  # noqa: E501

        :return: The customer_name of this RimeGetRIMEInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this RimeGetRIMEInfoResponse.

        Name of the customer who owns the license.  # noqa: E501

        :param customer_name: The customer_name of this RimeGetRIMEInfoResponse.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def expiration_time(self):
        """Gets the expiration_time of this RimeGetRIMEInfoResponse.  # noqa: E501

        Expiration time of the license.  # noqa: E501

        :return: The expiration_time of this RimeGetRIMEInfoResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._expiration_time

    @expiration_time.setter
    def expiration_time(self, expiration_time):
        """Sets the expiration_time of this RimeGetRIMEInfoResponse.

        Expiration time of the license.  # noqa: E501

        :param expiration_time: The expiration_time of this RimeGetRIMEInfoResponse.  # noqa: E501
        :type: datetime
        """

        self._expiration_time = expiration_time

    @property
    def grace_period_end_time(self):
        """Gets the grace_period_end_time of this RimeGetRIMEInfoResponse.  # noqa: E501

        After a license is expired, there is a grace period to allow a user to continue to use and update the license.  # noqa: E501

        :return: The grace_period_end_time of this RimeGetRIMEInfoResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._grace_period_end_time

    @grace_period_end_time.setter
    def grace_period_end_time(self, grace_period_end_time):
        """Sets the grace_period_end_time of this RimeGetRIMEInfoResponse.

        After a license is expired, there is a grace period to allow a user to continue to use and update the license.  # noqa: E501

        :param grace_period_end_time: The grace_period_end_time of this RimeGetRIMEInfoResponse.  # noqa: E501
        :type: datetime
        """

        self._grace_period_end_time = grace_period_end_time

    @property
    def ri_plan(self):
        """Gets the ri_plan of this RimeGetRIMEInfoResponse.  # noqa: E501


        :return: The ri_plan of this RimeGetRIMEInfoResponse.  # noqa: E501
        :rtype: RimeRIPlan
        """
        return self._ri_plan

    @ri_plan.setter
    def ri_plan(self, ri_plan):
        """Sets the ri_plan of this RimeGetRIMEInfoResponse.


        :param ri_plan: The ri_plan of this RimeGetRIMEInfoResponse.  # noqa: E501
        :type: RimeRIPlan
        """

        self._ri_plan = ri_plan

    @property
    def build_version(self):
        """Gets the build_version of this RimeGetRIMEInfoResponse.  # noqa: E501

        Annotated version of the Robust Intelligence cluster control plane, including the timestamp corresponding to the build.  # noqa: E501

        :return: The build_version of this RimeGetRIMEInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._build_version

    @build_version.setter
    def build_version(self, build_version):
        """Sets the build_version of this RimeGetRIMEInfoResponse.

        Annotated version of the Robust Intelligence cluster control plane, including the timestamp corresponding to the build.  # noqa: E501

        :param build_version: The build_version of this RimeGetRIMEInfoResponse.  # noqa: E501
        :type: str
        """

        self._build_version = build_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeGetRIMEInfoResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeGetRIMEInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Library defining the interface for the schedule API."""
from __future__ import annotations

import logging
from typing import NamedTuple

from rime_sdk.internal.rest_error_handler import RESTErrorHandler
from rime_sdk.swagger.swagger_client import (
    ApiClient,
    RimeGetScheduleResponse,
    RimeUpdateScheduleResponse,
)
from rime_sdk.swagger.swagger_client import ScheduleSchedule as ScheduleSchema
from rime_sdk.swagger.swagger_client import (
    ScheduleServiceApi,
    SchedulesScheduleScheduleIdUuidBody,
)

logger = logging.getLogger(__name__)


class ScheduleInfo(NamedTuple):
    """A named tuple for the schedule information."""

    project_id: str
    schedule_id: str
    test_run_config: dict
    frequency_cron_expr: str


class Schedule:
    """An interface for the schedule API.

    This interface provides methods to interact with the schedule API which allows
    you to manage schedules with various methods.

    Args:
        api_client: The API client.
        schedule_id: The schedule ID.
    """

    def __init__(self, api_client: ApiClient, schedule_id: str) -> None:
        """Initialize the schedule interface.

        Args:
            api_client: The API client.
            schedule_id: The schedule ID to interface with.
        """
        self._api_client = api_client
        self._schedule_id = schedule_id

    def __repr__(self) -> str:
        """Get the string representation of the schedule."""
        return f"{self.__class__.__name__}({self._schedule_id})"

    def __str__(self) -> str:
        """Get the string form of the schedule."""
        return f"Schedule  (ID: {self._schedule_id})"

    def __eq__(self, other: object) -> bool:
        """Check if the schedule is equal to another schedule."""
        if not isinstance(other, Schedule):
            return False

        return self._schedule_id == other._schedule_id

    @property
    def schedule_id(self) -> str:
        """Get the schedule ID.

        Returns:
            str: The schedule ID.
        """
        return self._schedule_id

    @property
    def info(self) -> ScheduleInfo:
        """Get the schedule information.

        Returns:
            dict: The schedule information.
        """
        schedule = self._get()
        return ScheduleInfo(
            project_id=schedule.project_id.uuid,
            schedule_id=schedule.schedule_id.uuid,
            test_run_config=schedule.test_run_config,
            frequency_cron_expr=schedule.frequency_cron_expr,
        )

    def _get(self) -> ScheduleSchema:
        """Get the schedule information.

        Returns:
            Schedule: The schedule information.
        """
        api = ScheduleServiceApi(self._api_client)
        with RESTErrorHandler():
            response: RimeGetScheduleResponse = api.schedule_service_get_schedule(
                schedule_id_uuid=self._schedule_id,
            )

            return response.schedule

    def update(
        self,
        frequency_cron_expr: str,
    ) -> ScheduleSchema:
        """Update the schedule.

        Args:
            frequency_cron_expr: The frequency cron expression.

        Returns:
            str: The updated schedule id.
        """
        if not self._schedule_id:
            raise ValueError(
                "No schedule ID has been attached to the object.  Please add a schedule ID to the object or create a new schedule."
            )
        api = ScheduleServiceApi(self._api_client)
        with RESTErrorHandler():
            body = SchedulesScheduleScheduleIdUuidBody(
                frequency_cron_expr=frequency_cron_expr,
            )

            response: RimeUpdateScheduleResponse = api.schedule_service_update_schedule(
                body=body,
                schedule_schedule_id_uuid=self._schedule_id,
                mask="frequency_cron_expr",
            )

            return response.schedule

    def delete(self) -> None:
        """Delete the schedule."""
        if not self._schedule_id:
            raise ValueError(
                "No schedule ID has been attached to the object.  Please add a schedule ID to the object or create a new schedule."
            )
        api = ScheduleServiceApi(self._api_client)
        with RESTErrorHandler():
            api.schedule_service_delete_schedule(schedule_id_uuid=self._schedule_id)
            self._schedule_id = ""



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativetestingModelConnectionSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'url': 'str',
        'http_headers': 'dict(str, str)',
        'endpoint_payload_template': 'str',
        'response_json_path': 'str'
    }

    attribute_map = {
        'url': 'url',
        'http_headers': 'httpHeaders',
        'endpoint_payload_template': 'endpointPayloadTemplate',
        'response_json_path': 'responseJsonPath'
    }

    def __init__(self, url=None, http_headers=None, endpoint_payload_template=None, response_json_path=None):  # noqa: E501
        """GenerativetestingModelConnectionSpec - a model defined in Swagger"""  # noqa: E501
        self._url = None
        self._http_headers = None
        self._endpoint_payload_template = None
        self._response_json_path = None
        self.discriminator = None
        self.url = url
        if http_headers is not None:
            self.http_headers = http_headers
        self.endpoint_payload_template = endpoint_payload_template
        self.response_json_path = response_json_path

    @property
    def url(self):
        """Gets the url of this GenerativetestingModelConnectionSpec.  # noqa: E501


        :return: The url of this GenerativetestingModelConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this GenerativetestingModelConnectionSpec.


        :param url: The url of this GenerativetestingModelConnectionSpec.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def http_headers(self):
        """Gets the http_headers of this GenerativetestingModelConnectionSpec.  # noqa: E501


        :return: The http_headers of this GenerativetestingModelConnectionSpec.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._http_headers

    @http_headers.setter
    def http_headers(self, http_headers):
        """Sets the http_headers of this GenerativetestingModelConnectionSpec.


        :param http_headers: The http_headers of this GenerativetestingModelConnectionSpec.  # noqa: E501
        :type: dict(str, str)
        """

        self._http_headers = http_headers

    @property
    def endpoint_payload_template(self):
        """Gets the endpoint_payload_template of this GenerativetestingModelConnectionSpec.  # noqa: E501


        :return: The endpoint_payload_template of this GenerativetestingModelConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_payload_template

    @endpoint_payload_template.setter
    def endpoint_payload_template(self, endpoint_payload_template):
        """Sets the endpoint_payload_template of this GenerativetestingModelConnectionSpec.


        :param endpoint_payload_template: The endpoint_payload_template of this GenerativetestingModelConnectionSpec.  # noqa: E501
        :type: str
        """
        if endpoint_payload_template is None:
            raise ValueError("Invalid value for `endpoint_payload_template`, must not be `None`")  # noqa: E501

        self._endpoint_payload_template = endpoint_payload_template

    @property
    def response_json_path(self):
        """Gets the response_json_path of this GenerativetestingModelConnectionSpec.  # noqa: E501

        A json path specifying where in the response json payload we can find the LLM's response response string. Note that the path must point to a string value in the json payload. Whitespace and other special characters can be encoded as unicode (\\u0020). Periods in json fields can be escaped with a backslash.  Example: - response payload: '{\"myfield\": {\"myotherfield\": \"Hey there!\"}}' - json path: \"myfield.myotherfield\"  Example: - response payload: '{\"myfield\": {\"myarr\": [\"Hey there!\"]}}' - json path: \"myfield.myarr.0\"  Example: - response payload: '{\"my.field\": \"hello\"}' - json path: \"my\\.field\"  The supported syntax is dot notation only as in the examples above.  # noqa: E501

        :return: The response_json_path of this GenerativetestingModelConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._response_json_path

    @response_json_path.setter
    def response_json_path(self, response_json_path):
        """Sets the response_json_path of this GenerativetestingModelConnectionSpec.

        A json path specifying where in the response json payload we can find the LLM's response response string. Note that the path must point to a string value in the json payload. Whitespace and other special characters can be encoded as unicode (\\u0020). Periods in json fields can be escaped with a backslash.  Example: - response payload: '{\"myfield\": {\"myotherfield\": \"Hey there!\"}}' - json path: \"myfield.myotherfield\"  Example: - response payload: '{\"myfield\": {\"myarr\": [\"Hey there!\"]}}' - json path: \"myfield.myarr.0\"  Example: - response payload: '{\"my.field\": \"hello\"}' - json path: \"my\\.field\"  The supported syntax is dot notation only as in the examples above.  # noqa: E501

        :param response_json_path: The response_json_path of this GenerativetestingModelConnectionSpec.  # noqa: E501
        :type: str
        """
        if response_json_path is None:
            raise ValueError("Invalid value for `response_json_path`, must not be `None`")  # noqa: E501

        self._response_json_path = response_json_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativetestingModelConnectionSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativetestingModelConnectionSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
